# Generated by roxygen2: do not edit by hand

S3method(print, roc.fits)
export(find.distr)
export(get.fits)
export(sm.coords)
import(pROC)
importFrom(MASS,fitdistr)
importFrom(stats,optimize)
importFrom(stats,pgamma)
importFrom(stats,plnorm)
importFrom(stats,pnorm)
importFrom(stats,pweibull)
importFrom(stats,qgamma)
importFrom(stats,qlnorm)
importFrom(stats,qnorm)
importFrom(stats,qweibull)
importFrom(stats,setNames)
importFrom(stats,uniroot)
