#' Print distribution fits retrieved from smoothed ROC curves
#'
#' @param x
#' A `roc.fits` object generated by [get.fits()].
#'
#' @param ... Further arguments passed to or from other methods.
#'
#' @return
#' A console printed summary including the fitted case and control distribution families, parameters, and AIC values.
#'
#' @rawNamespace S3method(print, roc.fits)
#' @noRd

print.roc.fits<-function(x,...){

  fit<-x

  cat("Fitted distributions for smoothed ROC curve\n\n")

  for(grp in c("controls", "cases")){
    cat(tools::toTitleCase(grp), ":\n", sep="")
    cat("  Distribution: ", fit[[grp]]$distribution, "\n", sep="")
    cat("  Parameters:\n")
    print(fit[[grp]]$parameters)
    cat("  AIC: ", signif(fit[[grp]]$aic, 4), "\n\n", sep="")
  }

  invisible(fit)
}
