% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/blood_data.R
\docType{data}
\name{blood_data}
\alias{blood_data}
\title{Example blood biomarker dataset.}
\format{
A data frame with one column containing stroke diagnoses and another column containing plasma neurofilament-light chain levels in pg/mL.
}
\description{
A real-world dataset containing plasma neurofilament-light chain (NfL) levels measured in 33 neurologically normal controls and 14 patients diagnosed with ischemic stroke as described by O'Connell et al. (2020).
}
\examples{
#load example dataset

data(blood_data)

#return dataset structure

str(blood_data)

}
\references{
O'Connell, GC., Alder, ML., Smothers, CG., Still, CH., Webel, AR., & Moore, S.M. (2020).
Diagnosis of ischemic stroke using circulating levels of brain-specific proteins measured via high-sensitivity digital ELISA.
\emph{Brain Research}, 15, 1739.
\doi{10.1016/j.brainres.2020.146861}
}
